#if !defined(lint) && !defined(__INSIGHT__)
static char sos__rcsid[] = "$Id$";
static char sos__copyright[] = "Copyright (c) 1994, 1995, 1996 SOS Corporation";
static char sos__contact[] = "SOS Corporation <sos-info@soscorp.com> +1 800 SOS UNIX";
#endif /* not lint */

/*
 * ++Copyright Released Product++
 *
 * Copyright (c) 1994, 1995, 1996 Sources of Supply Corporation ("SOS").
 * All rights reserved.
 *
 * The SOS Released Product License Agreement specifies the terms and
 * conditions for redistribution.  You may find the License Agreement
 * in the file LICENSE.
 *
 * SOS Corporation
 * 461 5th Ave.; 16th floor
 * New York, NY 10017
 *
 * +1 800 SOS UNIX
 * <sos-info@soscorp.com>
 *
 * --Copyright Released Product--
 */

#include "sos.h"

int sos_errno;			
char *sos_errlist[] = 
{
  "No error",			/* 0 */
  "System Error",		/* 1 */
  "Invalid Argument",		/* 2 */
  NULL
};

void
sos_perror(char *s)
{

  if ( sos_errno == SOS_ERRNO_SYS )
    fprintf(stderr, "%s: %s: %s\n", s, 
	    sos_errlist[sos_errno],
	    strerror(errno));
  else
    fprintf(stderr, "%s: %s\n", s, sos_errlist[sos_errno]);
}
